% =========================================================================
% This program calculates steady state implications of an
% increase in alpha for the high type. 
% =========================================================================
%% -------------------------------------------------------------------------
% Initialize parameters and other model primitives
% -------------------------------------------------------------------------
clc
clear all
close all

mstar = 100 ;

% Fixed Parameters
beta      = 1/1.04; % Discount rate
alpha_l   = 0.64 ; % Returns to scale of low type
cf_l      = 2.298950284374937;    % Fixed cost - intercept% 
sigma0    = 1.331137767741511;    % Variance of startup distribution (\sigma_G^2)
mu_l      = -2.431373086987380;   % Long-run AR1 mean of high type  
mu_h      = -1.436111629482697 ;   % Long-run AR1 mean of high type
cf_h      = 24.308026243791222;    % Fixed cost - intercept
rho       = 0.984150757243253;    % Persistence  of AR1
sigma_eps = 0.245520815536363;    % Variance of AR1 innovations
s0        = -4.344376541584754;  % Mean of startup distribution (\mu_g)
omega_h   = 0.359430723369395;    % Share of high type firms
g         = 0.026513188 ; % 1978 labor force growth
ce        = 0.012815402736800;            % entry cost

ns = 100 ; % number of points in grid
tol = 1e-6 ; % Specify tolerance

%------------------------------------------

% Returns to Scale Experiment
alpha_h = 0.66053 ; % Increase in returns to scale of high type to match concentration

%------------------------------------------
omega_l = 1 - omega_h;

% Productivity grid using Tauchen method
[svec, F_l, F_h] = tauchen2(mu_l, mu_h, rho, sigma_eps, ns) ; 

% [svec, Fh, Fl] = tauchen2(muh, mul, rho, sigma_eps, ns) ; 
F_l = transpose(F_l) ; % Transpose so that column sum to one
F_h = transpose(F_h) ; % Transpose so that column sum to one

% Startup productivity
step = svec(2) - svec(1) ;
G = normcdf(svec + step/2, s0, sigma0) ;
G(2:end-1) = G(2:end-1) - G(1:end-2) ;
G(end) = 1 - sum(G(1:end-1)) ;

% Create a structure that we want to transfer to functions
params.ce = ce;
params.beta = beta ;
params.g = g ;
params.mstar = mstar ;
params.sigma0 = sigma0 ;
params.ns = ns ;
params.svec = svec ;
params.G = G ;
params.tol = tol ;
params.F_h = F_h;
params.F_l = F_l;
params.omega_h = omega_h;
params.cf_h = cf_h;
params.cf_l = cf_l;
params.alpha_h = alpha_h ;
params.alpha_l = alpha_l ;


% MAIN CHANGE: Take ce as given, solve for zstar that clears entry condition
fun1 = @(zstar)zstar_fun(zstar, params) ;
[zstar, ~] = fzero(fun1, 1.2) ;%fzero(fun1, 1/10) ;%fzero(fun1, 2) ;
params.zstar = zstar ;

% Solve for value functions vh and vl and thresholds sstar_indh and
% sstar_indl
v_h = vfn(F_h, zstar, cf_h, alpha_h, params)  ;
sstar_ind_h = find(v_h) ;
if (isempty(sstar_ind_h))
    stateqbm.flag = 0 ;
    f = results ;
    return
else
    sstar_ind_h = sstar_ind_h(1) ;
end

v_l = vfn(F_l, zstar, cf_l, alpha_l, params)  ;
sstar_ind_l = find(v_l) ;
if (isempty(sstar_ind_l))
    stateqbm.flag = 0 ;
    f = results ;
    return
else
    sstar_ind_l = sstar_ind_l(1) ;
end


% Find stationary distribution(s) for each mu type

% Start with stationary distribution before exit
Gnew_h = G ;
Gnew_h(1:sstar_ind_h-1) = 0 ;

% New transition matrix to account for exit
Fnew_h = F_h ;
Fnew_h(:,1:sstar_ind_h-1) = zeros(ns, sstar_ind_h-1) ;

% Find m0 such that labor markets clear
I = eye(ns) ;
mustar_h = (I - Fnew_h/(1+g)) \ (omega_h*mstar*Gnew_h) ;
mustar_h(1:sstar_ind_h-1) = 0 ;

% Start with stationary distribution before exit
Gnew_l = G ;
Gnew_l(1:sstar_ind_l-1) = 0 ;

% New transition matrix to account for exit
Fnew_l = F_l ;
Fnew_l(:,1:sstar_ind_l-1) = zeros(ns, sstar_ind_l-1) ;

% Find m0 such that labor markets clear
I = eye(ns) ;
mustar_l = (I - Fnew_l/(1+g)) \ (omega_l*mstar*Gnew_l) ;
mustar_l(1:sstar_ind_l-1) = 0 ;

% calculate employment at each firm

nstar_h = n(svec, zstar, alpha_h) + cf_h;
nstar_h(1:sstar_ind_h-1) = 0 ;

nstar_l = n(svec, zstar, alpha_l) + cf_l;
nstar_l(1:sstar_ind_l-1) = 0 ;

N = sum(nstar_h.*mustar_h) + sum(nstar_l.*mustar_l) + mstar*ce;

avg_fsize = (sum(nstar_h.*mustar_h)+sum(nstar_l.*mustar_l))/(sum(mustar_h)+sum(mustar_l)) ;

startup_rate = mstar*(omega_h*sum(Gnew_h)+omega_l*sum(Gnew_l))/((sum(mustar_h)+sum(mustar_l))/(1+g)) ;

startup_share_h = omega_h*sum(Gnew_h)/(omega_h*sum(Gnew_h)+omega_l*sum(Gnew_l));
startup_share_l = omega_l*sum(Gnew_l)/(omega_h*sum(Gnew_h)+omega_l*sum(Gnew_l));

% -------------------------------------------------------------------------
% Calculate other steady state outcomes
% -------------------------------------------------------------------------

ageub = 250 ;
age=transpose(0:ageub) ;


% Lifecycle Profile for high mu

cohevol_h(:,1) = Gnew_h/sum(Gnew_h) ;
dist_h(:,1) = cohevol_h(:,1)/sum(cohevol_h(:,1)) ;

avg_fsize_age_h(1) = sum(nstar_h .* dist_h(:,1)) ;
cohevol_emp_h(:,1) = cohevol_h(:,1).*nstar_h ;
for i=2:ageub+1
        
    cohevol_h(:,i) = Fnew_h * cohevol_h(:,i-1) ;
    cohevol_h(1:sstar_ind_h-1,i) = 0 ;
    dist_h(:,i) = cohevol_h(:,i)/sum(cohevol_h(:,i)) ;

    exit_rate_age_h(i-1,1) = (sum(cohevol_h(:,i-1)) - sum(cohevol_h(:,i)))/sum(cohevol_h(:,i-1)) ;
    avg_fsize_age_h(i,1) = sum(nstar_h .* dist_h(:,i)) ;

    cohevol_emp_h(:,i) = cohevol_h(:,i).*nstar_h ;
end
% Unconditional survival probability by age
St_h = sum(cohevol_h(:,1:end)) ;

% Lifecycle Profile for low mu

cohevol_l(:,1) = Gnew_l/sum(Gnew_l) ;
dist_l(:,1) = cohevol_l(:,1)/sum(cohevol_l(:,1)) ;

avg_fsize_age_l(1) = sum(nstar_l .* dist_l(:,1)) ;
cohevol_emp_l(:,1) = cohevol_l(:,1).*nstar_l ;
for i=2:ageub+1
       
    cohevol_l(:,i) = Fnew_l * cohevol_l(:,i-1) ;
    cohevol_l(1:sstar_ind_l-1,i) = 0 ;
    dist_l(:,i) = cohevol_l(:,i)/sum(cohevol_l(:,i)) ;

    exit_rate_age_l(i-1,1) = (sum(cohevol_l(:,i-1)) - sum(cohevol_l(:,i)))/sum(cohevol_l(:,i-1)) ;
    avg_fsize_age_l(i,1) = sum(nstar_l .* dist_l(:,i)) ;
    cohevol_emp_l(:,i) = cohevol_l(:,i).*nstar_l ;
end

% Unconditional survival probability by age
St_l = sum(cohevol_l(:,1:end)) ;

% Unconditional survival probability by age, for aggregate
St = (startup_share_l * St_l + startup_share_h * St_h);
exit_rate_age =  (St(1:end-1)-St(2:end))./St(1:end-1);
age_weight_l = (startup_share_l*St_l')./(startup_share_l* St_l' + startup_share_h * St_h');
age_weight_h = (startup_share_h*St_h')./(startup_share_l* St_l' + startup_share_h * St_h');
avg_fsize_age = age_weight_l.* avg_fsize_age_l + age_weight_h.* avg_fsize_age_h;

% 250+ cutoff
ind_size250_h = find(nstar_h >= 250) ;
ind_size250_l = find(nstar_l >= 250) ;

% Concentration by type
conc_h = sum(mustar_h(ind_size250_h:end).*nstar_h(ind_size250_h:end))/sum(mustar_h.*nstar_h);
conc_l = sum(mustar_l(ind_size250_l:end).*nstar_l(ind_size250_l:end))/sum(mustar_l.*nstar_l);

emp_share_h = sum(mustar_h.*nstar_h)/(sum(mustar_h.*nstar_h)+sum(mustar_l.*nstar_l));
emp_share_l = sum(mustar_l.*nstar_l)/(sum(mustar_h.*nstar_h)+sum(mustar_l.*nstar_l));

% Aggregate Concentration 
conc = conc_h*emp_share_h + conc_l*emp_share_l;

% Distribution of firms by age 
age_dist = transpose(St)./((1+g).^age) ;

% The last age is interpreted as all firms above that age
age_dist(end) = age_dist(end)/exit_rate_age(end) ;
age_dist = age_dist/sum(age_dist) ;


% Distribution of employment by age
age_empdist = age_dist .* avg_fsize_age ;
age_empdist = age_empdist/sum(age_empdist) ;

% Distribution of employment by age by type
age_dist_h = transpose(St_h)./((1+g).^age) ;
age_dist_h(end) = age_dist_h(end)/exit_rate_age_h(end) ;
age_dist_h = age_dist_h/sum(age_dist_h) ;
age_empdist_h = age_dist_h .* avg_fsize_age_h ;
age_empdist_h = age_empdist_h/sum(age_empdist_h) ;

age_dist_l = transpose(St_l)./((1+g).^age) ;
age_dist_l(end) = age_dist_l(end)/exit_rate_age_l(end) ;
age_dist_l = age_dist_l/sum(age_dist_l) ;
age_empdist_l = age_dist_l .* avg_fsize_age_l ;
age_empdist_l = age_empdist_l/sum(age_empdist_l) ;

% Age-size distribution
szage_mass_h = cohevol_h./repmat(transpose((1+g).^age), [size(cohevol_h,1) 1]) ;
szageemp_mass_h = szage_mass_h.*repmat(nstar_h, [1 size(szage_mass_h,2)]) ;

szage_mass_l = cohevol_l./repmat(transpose((1+g).^age), [size(cohevol_l,1) 1]) ;
szageemp_mass_l = szage_mass_l.*repmat(nstar_l, [1 size(szage_mass_l,2)]) ;

for i=1:ageub+1
     conc_age_h(i,1) = sum(szageemp_mass_h(ind_size250_h:end, i)/sum(szageemp_mass_h(:, i))) ;
     conc_age_l(i,1) = sum(szageemp_mass_l(ind_size250_l:end, i)/sum(szageemp_mass_l(:, i))) ;
     emp_share_age_h(i,1) = sum(startup_share_h*szageemp_mass_h(:, i))/(sum(startup_share_h*szageemp_mass_h(:, i))+sum(startup_share_l*szageemp_mass_l(:, i)));
     emp_share_age_l(i,1) = 1 - emp_share_age_h(i,1);
     conc_age(i,1) = conc_age_h(i,1)*emp_share_age_h(i,1) + conc_age_l(i,1)*emp_share_age_l(i,1) ;
end



%% Verify that startup rate equals labor force growth rate plus exit rate
% We will do so by feeding a time series for labor that grows at a
% constant rate and solving for a fill in the blanks equilibrium

tau = 100 ;
t = transpose(0:tau) ;
Ns(1) = N ;
for i=2:length(t)
    Ns(i,1) = Ns(i-1)*(1+g) ;
end

% Specify the matrix to store firm-size distribution for each t, high type
MU_h = zeros(length(mustar_h), length(t)) ;
MU_h(:,1) = mustar_h ;

MUemp_h = zeros(length(mustar_h), length(t)) ;
MUemp_h(:,1) = MU_h(:,1).* nstar_h ;

It_h(:,1) = Fnew_h*(mustar_h/(1+g)) ;
It_h(1:sstar_ind_h-1,1) = 0 ;
mtUn_h(1) = omega_h*mstar ;
MtUn_h(1) = sum(It_h(:,1)) + mtUn_h(1) ;
Mt_h(1) = sum(MU_h(:,1)) ;
Xt_h(1) = Mt_h(1)/(1+g) - sum(It_h(:,1)) ;

% Compute the evolution of the age distribution
MU_age_h = zeros(length(age), length(t)) ;
MU_age_h(:,1) = age_dist_h*Mt_h(1) ;

% Employment distribution by age
MUemp_age_h = zeros(length(age), length(t)) ;
MUemp_age_h(:,1) = age_empdist_h*Ns(1) ;

% Specify the matrix to store firm-size distribution for each t, low type
MU_l = zeros(length(mustar_l), length(t)) ;
MU_l(:,1) = mustar_l ;

MUemp_l = zeros(length(mustar_l), length(t)) ;
MUemp_l(:,1) = MU_l(:,1).* nstar_l;

Mt_l(1) = sum(MU_l(:,1)) ;

It_l(:,1) = Fnew_l*(mustar_l/(1+g)) ;
It_l(1:sstar_ind_l-1,1) = 0 ;

mtUn_l(1) = omega_l*mstar ;
MtUn_l(1) = sum(It_l(:,1)) + mtUn_l(1) ;

Xt_l(1) = Mt_l(1)/(1+g) - sum(It_l(:,1)) ;

% Compute the evolution of the age distribution
MU_age_l = zeros(length(age), length(t)) ;
MU_age_l(:,1) = age_dist_h*Mt_l(1) ;

% Employment distribution by age
MUemp_age_l = zeros(length(age), length(t)) ;
MUemp_age_l(:,1) = age_empdist_l*Ns(1) ;

% Some aggregates
Mt(1) = Mt_l(1)+Mt_h(1);
AFSt(1) = (sum(nstar_l .* MU_l(:,1))+(sum(nstar_h .* MU_h(:,1))))/(Mt_l(1)+Mt_h(1)) ;
startup_rate_t(1) = startup_rate ;
exit_rate_t(1) = (Xt_l(1)+Xt_h(1))/(Mt_l(1)+Mt_h(1))*(1+g) ;

avg_stsizeU = ce + omega_h*sum(nstar_h.*Gnew_h) + omega_l*sum(nstar_l.*Gnew_l); % Denominator of dyn equation: Total employment of 0-year old firms + entry cost.

% % Now let's iterate forward by time-periods and calculate evolution of M
for i=2:length(t)
   It_h(:,i) = Fnew_h*MU_h(:,i-1) ;
   It_h(1:sstar_ind_h-1,i) = 0;

   It_l(:,i) = Fnew_l*MU_l(:,i-1) ;
   It_l(1:sstar_ind_l-1,i) = 0;

%    It(:,i) = It_l(:,i)+ It_h(:,i); 
   
   Nd_inc = sum(nstar_h .* It_h(:,i)) + sum(nstar_l .* It_l(:,i));
   Nd_res = Ns(i) - Nd_inc ;
   
   m = Nd_res/avg_stsizeU;
   
   % Calculate evolution for high types
   mtUn_h(i,1) = omega_h*m ;  
   mth(i) = mtUn_h(i)*sum(Gnew_h) ;
   MU_h(:,i) = mtUn_h(i,1)*Gnew_h +  It_h(:,i) ;
   MUemp_h(:,i) = MU_h(:,i).* nstar_h;
   Mt_h(i,1) = sum(MU_h(:,i)) ;
   Xt_h(i) = Mt_h(i-1) - sum(It_h(:,i)) ;
 
   % Calculate evolution for low types
   mtUn_l(i,1) = omega_l*m ;
   mtl(i) = mtUn_l(i)*sum(Gnew_l) ;
   MU_l(:,i) = mtUn_l(i,1)*Gnew_l +  It_l(:,i) ;
   MUemp_l(:,i) = MU_l(:,i).* nstar_l;
   Mt_l(i,1) = sum(MU_l(:,i)) ;
   Xt_l(i) = Mt_l(i-1) - sum(It_l(:,i)) ;
   
   Mt(i) = Mt_l(i)+Mt_h(i);
   mt(i) = mtl(i)+mth(i);
   Xt(i) = Xt_l(i)+Xt_h(i);
   
 
   % measured aggregates
    AFSt(i,1) = (sum(nstar_l.* MU_l(:,i))+(sum(nstar_h.* MU_h(:,i))))/Mt(i) ;
    startup_rate_t(i) = mt(i)/Mt(i-1);
    exit_rate_t(i) = Xt(i)/Mt(i-1) ;
   
end

%%
alteqbm_hrts.startup_rate = startup_rate;
alteqbm_hrts.exit_rate = exit_rate_t(1);
alteqbm_hrts.avg_fsize = avg_fsize;
alteqbm_hrts.conc = conc;

alteqbm_hrts.exit_rate_age = exit_rate_age;
alteqbm_hrts.avg_fsize_age = avg_fsize_age;
alteqbm_hrts.conc_age = conc_age;

alteqbm_hrts.age_dist = age_dist;
alteqbm_hrts.age_empdist = age_empdist;

save ../alteqbm_hrts alteqbm_hrts
